==> mktcenter-service-2.0.0-20191126.092844-27-sources.jar: com/bizvane/mktcenterservice/models/po/MktCouponIntegralExchangePO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.io.Serializable;
import java.util.Date;

public class MktCouponIntegralExchangePO implements Serializable {

	/**
	 * 只读. . exchange_id
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "exchangeId", required = false, example = "")
	private Long exchangeId;
	/**
	 * 只读. 编号. exchange_code
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "编号", name = "exchangeCode", required = false, example = "")
	private String exchangeCode;
	/**
	 * 只读. 品牌id. sys_brand_id
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 券id存的是券定义id. coupon_entity_id
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "券id存的是券定义id", name = "couponEntityId", required = false, example = "")
	private Long couponEntityId;
	/**
	 * 只读. 券名称. coupon_name
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "券名称", name = "couponName", required = false, example = "")
	private String couponName;
	/**
	 * 只读. 积分兑换价格. exchange_price
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分兑换价格", name = "exchangePrice", required = false, example = "")
	private Integer exchangePrice;
	/**
	 * 只读. 是否限制库存数量 0：不限制 1：限制. store_status
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否限制库存数量 0：不限制 1：限制", name = "storeStatus", required = false, example = "")
	private Integer storeStatus;
	/**
	 * 只读. 限制库存数量. store_count
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "限制库存数量", name = "storeCount", required = false, example = "")
	private Long storeCount;
	/**
	 * 只读. 是否限兑 0：不限制 1：限制. exchange_status
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否限兑 0：不限制 1：限制", name = "exchangeStatus", required = false, example = "")
	private Integer exchangeStatus;
	/**
	 * 只读. 如果限制，限制数量. exchange_count
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "如果限制，限制数量", name = "exchangeCount", required = false, example = "")
	private Long exchangeCount;
	/**
	 * 只读. 已经兑换数量. already_exchange_count
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "已经兑换数量", name = "alreadyExchangeCount", required = false, example = "")
	private Long alreadyExchangeCount;
	/**
	 * 只读. 会员范围 0:全部会员 1：部分会员. store_scope
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员范围 0:全部会员 1：部分会员", name = "storeScope", required = false, example = "")
	private Integer storeScope;
	/**
	 * 只读. 上架状态 0：下架 1：上架. sales_status
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "上架状态 0：下架 1：上架", name = "salesStatus", required = false, example = "")
	private Integer salesStatus;
	/**
	 * 只读. 是否限制会员等级 0=否   1=是. mbr_level_status
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否限制会员等级 0=否   1=是", name = "mbrLevelStatus", required = false, example = "")
	private Boolean mbrLevelStatus;
	/**
	 * 只读. 会员等级Id集. mbr_level_ids
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员等级Id集", name = "mbrLevelIds", required = false, example = "")
	private String mbrLevelIds;
	/**
	 * 只读. 排序值. order_num
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "排序值", name = "orderNum", required = false, example = "")
	private Integer orderNum;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modify_user_id
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserId", required = false, example = "")
	private Long modifyUserId;
	/**
	 * 只读. . modify_user_name
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserName", required = false, example = "")
	private String modifyUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getExchangeId() {
		return exchangeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setExchangeId(Long exchangeId) {
		this.exchangeId = exchangeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public String getExchangeCode() {
		return exchangeCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setExchangeCode(String exchangeCode) {
		this.exchangeCode = exchangeCode == null ? null : exchangeCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getCouponEntityId() {
		return couponEntityId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setCouponEntityId(Long couponEntityId) {
		this.couponEntityId = couponEntityId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public String getCouponName() {
		return couponName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setCouponName(String couponName) {
		this.couponName = couponName == null ? null : couponName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Integer getExchangePrice() {
		return exchangePrice;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setExchangePrice(Integer exchangePrice) {
		this.exchangePrice = exchangePrice;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Integer getStoreStatus() {
		return storeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setStoreStatus(Integer storeStatus) {
		this.storeStatus = storeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getStoreCount() {
		return storeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setStoreCount(Long storeCount) {
		this.storeCount = storeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Integer getExchangeStatus() {
		return exchangeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setExchangeStatus(Integer exchangeStatus) {
		this.exchangeStatus = exchangeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getExchangeCount() {
		return exchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setExchangeCount(Long exchangeCount) {
		this.exchangeCount = exchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getAlreadyExchangeCount() {
		return alreadyExchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setAlreadyExchangeCount(Long alreadyExchangeCount) {
		this.alreadyExchangeCount = alreadyExchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Integer getStoreScope() {
		return storeScope;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setStoreScope(Integer storeScope) {
		this.storeScope = storeScope;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Integer getSalesStatus() {
		return salesStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setSalesStatus(Integer salesStatus) {
		this.salesStatus = salesStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Boolean getMbrLevelStatus() {
		return mbrLevelStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setMbrLevelStatus(Boolean mbrLevelStatus) {
		this.mbrLevelStatus = mbrLevelStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public String getMbrLevelIds() {
		return mbrLevelIds;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setMbrLevelIds(String mbrLevelIds) {
		this.mbrLevelIds = mbrLevelIds == null ? null : mbrLevelIds.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Integer getOrderNum() {
		return orderNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setOrderNum(Integer orderNum) {
		this.orderNum = orderNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Long getModifyUserId() {
		return modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setModifyUserId(Long modifyUserId) {
		this.modifyUserId = modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public String getModifyUserName() {
		return modifyUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setModifyUserName(String modifyUserName) {
		this.modifyUserName = modifyUserName == null ? null : modifyUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-07-18 14:52:00
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}

==> mktcenter-service-2.0.0-20200323.084943-42-sources.jar: com/bizvane/mktcenterservice/models/po/MktCouponIntegralExchangePO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.io.Serializable;
import java.util.Date;

public class MktCouponIntegralExchangePO implements Serializable {

	/**
	 * 只读. . exchange_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "exchangeId", required = false, example = "")
	private Long exchangeId;
	/**
	 * 只读. 编号. exchange_code
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "编号", name = "exchangeCode", required = false, example = "")
	private String exchangeCode;
	/**
	 * 只读. 品牌id. sys_brand_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 券id存的是券定义id. coupon_entity_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "券id存的是券定义id", name = "couponEntityId", required = false, example = "")
	private Long couponEntityId;
	/**
	 * 只读. 分类id，用来与商城商品分类统一用. classify_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "分类id，用来与商城商品分类统一用", name = "classifyId", required = false, example = "")
	private Integer classifyId;
	/**
	 * 只读. 券名称. coupon_name
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "券名称", name = "couponName", required = false, example = "")
	private String couponName;
	/**
	 * 只读. 积分兑换价格. exchange_price
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分兑换价格", name = "exchangePrice", required = false, example = "")
	private Integer exchangePrice;
	/**
	 * 只读. 是否限制库存数量 0：不限制 1：限制. store_status
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否限制库存数量 0：不限制 1：限制", name = "storeStatus", required = false, example = "")
	private Integer storeStatus;
	/**
	 * 只读. 限制库存数量. store_count
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "限制库存数量", name = "storeCount", required = false, example = "")
	private Long storeCount;
	/**
	 * 只读. 是否限兑 0：不限制 1：限制. exchange_status
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否限兑 0：不限制 1：限制", name = "exchangeStatus", required = false, example = "")
	private Integer exchangeStatus;
	/**
	 * 只读. 如果限制，限制数量. exchange_count
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "如果限制，限制数量", name = "exchangeCount", required = false, example = "")
	private Long exchangeCount;
	/**
	 * 只读. 已经兑换数量. already_exchange_count
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "已经兑换数量", name = "alreadyExchangeCount", required = false, example = "")
	private Long alreadyExchangeCount;
	/**
	 * 只读. 会员范围 0:全部会员 1：部分会员. store_scope
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员范围 0:全部会员 1：部分会员", name = "storeScope", required = false, example = "")
	private Integer storeScope;
	/**
	 * 只读. 上架状态 0：下架 1：上架. sales_status
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "上架状态 0：下架 1：上架", name = "salesStatus", required = false, example = "")
	private Integer salesStatus;
	/**
	 * 只读. 是否限制会员等级 0=否   1=是. mbr_level_status
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否限制会员等级 0=否   1=是", name = "mbrLevelStatus", required = false, example = "")
	private Boolean mbrLevelStatus;
	/**
	 * 只读. 会员等级Id集. mbr_level_ids
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员等级Id集", name = "mbrLevelIds", required = false, example = "")
	private String mbrLevelIds;
	/**
	 * 只读. 排序值. order_num
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "排序值", name = "orderNum", required = false, example = "")
	private Integer orderNum;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modify_user_id
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserId", required = false, example = "")
	private Long modifyUserId;
	/**
	 * 只读. . modify_user_name
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserName", required = false, example = "")
	private String modifyUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 组织code. organization_code
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	@io.swagger.annotations.ApiModelProperty(value = "组织code", name = "organizationCode", required = false, example = "")
	private String organizationCode;
	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getExchangeId() {
		return exchangeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setExchangeId(Long exchangeId) {
		this.exchangeId = exchangeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public String getExchangeCode() {
		return exchangeCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setExchangeCode(String exchangeCode) {
		this.exchangeCode = exchangeCode == null ? null : exchangeCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getCouponEntityId() {
		return couponEntityId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setCouponEntityId(Long couponEntityId) {
		this.couponEntityId = couponEntityId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getClassifyId() {
		return classifyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setClassifyId(Integer classifyId) {
		this.classifyId = classifyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public String getCouponName() {
		return couponName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setCouponName(String couponName) {
		this.couponName = couponName == null ? null : couponName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getExchangePrice() {
		return exchangePrice;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setExchangePrice(Integer exchangePrice) {
		this.exchangePrice = exchangePrice;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getStoreStatus() {
		return storeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setStoreStatus(Integer storeStatus) {
		this.storeStatus = storeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getStoreCount() {
		return storeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setStoreCount(Long storeCount) {
		this.storeCount = storeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getExchangeStatus() {
		return exchangeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setExchangeStatus(Integer exchangeStatus) {
		this.exchangeStatus = exchangeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getExchangeCount() {
		return exchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setExchangeCount(Long exchangeCount) {
		this.exchangeCount = exchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getAlreadyExchangeCount() {
		return alreadyExchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setAlreadyExchangeCount(Long alreadyExchangeCount) {
		this.alreadyExchangeCount = alreadyExchangeCount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getStoreScope() {
		return storeScope;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setStoreScope(Integer storeScope) {
		this.storeScope = storeScope;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getSalesStatus() {
		return salesStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setSalesStatus(Integer salesStatus) {
		this.salesStatus = salesStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Boolean getMbrLevelStatus() {
		return mbrLevelStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setMbrLevelStatus(Boolean mbrLevelStatus) {
		this.mbrLevelStatus = mbrLevelStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public String getMbrLevelIds() {
		return mbrLevelIds;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setMbrLevelIds(String mbrLevelIds) {
		this.mbrLevelIds = mbrLevelIds == null ? null : mbrLevelIds.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Integer getOrderNum() {
		return orderNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setOrderNum(Integer orderNum) {
		this.orderNum = orderNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Long getModifyUserId() {
		return modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setModifyUserId(Long modifyUserId) {
		this.modifyUserId = modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public String getModifyUserName() {
		return modifyUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setModifyUserName(String modifyUserName) {
		this.modifyUserName = modifyUserName == null ? null : modifyUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public String getOrganizationCode() {
		return organizationCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-02-20 14:10:23
	 */
	public void setOrganizationCode(String organizationCode) {
		this.organizationCode = organizationCode == null ? null : organizationCode.trim();
	}
}
